/* eslint-disable no-unused-vars */

import React, { useState } from 'react';
import styled from 'styled-components';
import { Input, Button, Form, notification } from 'antd';
import { useHistory } from 'react-router-dom';

const validateMessages = {
  required: 'Password is required!',
  types: {
    email: `Email is not validate`,
  },
  number: {
    // eslint-disable-next-line no-template-curly-in-string
    range: 'Password must be between ${min} and ${max}',
  },
};

const openNotificationWithIcon = type => {
  notification[type]({
    message: 'Done. Change password succeed',
  });
};

const ForgotPasswordPage = () => {
  const history = useHistory();
  const [toggleState, setToggleState] = useState(true);
  const [newPassword, setNewPassword] = useState();

  const onFinish = values => {
    console.log(values);
    setToggleState(false);
  };

  const updateNewPassword = event => {
    console.log('new password', newPassword);
    openNotificationWithIcon('success');
    history.push('/');
  };
  return (
    <Wrapper>
      <Cover>
        <Content>
          <Title>Forgot password</Title>
          {toggleState ? (
            <Form onFinish={onFinish} validateMessages={validateMessages}>
              <Form.Item name={['user', 'email']} rules={[{ type: 'email' }]}>
                <StyledInput placeholder="Enter your email" />
              </Form.Item>
              <Form.Item>
                <Button htmlType="submit" type="primary" block>
                  Verify
                </Button>
              </Form.Item>
            </Form>
          ) : (
            <Form onFinish={onFinish} validateMessages={validateMessages}>
              <Form.Item
                name={['user', 'password']}
                rules={[{ required: true, min: 8, max: 30 }]}
              >
                <StyledInput
                  onChange={event => setNewPassword(event.target.value)}
                  placeholder="Enter your new password"
                />
              </Form.Item>
              <Form.Item>
                <Button
                  onClick={event => updateNewPassword(event)}
                  type="primary"
                  block
                >
                  Submit
                </Button>
              </Form.Item>
            </Form>
          )}
        </Content>
      </Cover>
    </Wrapper>
  );
};

const StyledInput = styled(Input)``;

const Title = styled.h1`
  text-align: center;
`;

const Content = styled.div`
  margin: 20px;
`;

const Cover = styled.div`
  width: 400px;
  background-color: white;
  border-radius: 3px;
`;

const Wrapper = styled.div`
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #1890ff;
`;

export default ForgotPasswordPage;
