/**
 *
 * ForgotPasswordPage
 *
 */
/* eslint-disable no-unused-vars */
import React, { useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import styled from 'styled-components';
import { Button, notification } from 'antd';
import { Input, Form } from 'formik-antd';
import { Formik } from 'formik';
import axios from 'axios';
import makeSelectForgotPasswordPage from './selectors';
import reducer from './reducer';
import saga from './saga';
import validationSchema from './Validation.Shema';

const stateSelector = createStructuredSelector({
  forgotPasswordPage: makeSelectForgotPasswordPage(),
});

const initialValues = {
  email: '',
};

export default function ForgotPasswordPage() {
  useInjectReducer({ key: 'forgotPasswordPage', reducer });
  useInjectSaga({ key: 'forgotPasswordPage', saga });

  /* eslint-disable no-unused-vars */
  const { forgotPasswordPage } = useSelector(stateSelector);
  const dispatch = useDispatch();
  /* eslint-enable no-unused-vars */

  const onSubmit = async values => {
    try {
      await axios.post(
        `http://5f34fe339124200016e193eb.mockapi.io/videoCall/Auth`,
        values,
      );
      notification.success({
        message: 'Send reset password link successfully',
      });
    } catch (e) {
      notification.error({
        message: 'Failed to send reset password to email!',
      });
    }
  };

  return (
    <Wrapper>
      <Cover>
        <Content>
          <Title>Forgot password</Title>
          <Formik
            initialValues={initialValues}
            onSubmit={onSubmit}
            validationSchema={validationSchema}
          >
            <Form>
              <Form.Item name="email" required>
                <StyledInput
                  type="email"
                  name="email"
                  autoFocus
                  placeholder="Enter your email"
                />
              </Form.Item>
              <ButtonStyle htmlType="submit" type="primary">
                Submit
              </ButtonStyle>
            </Form>
          </Formik>
        </Content>
      </Cover>
    </Wrapper>
  );
}

const StyledInput = styled(Input)`
  padding: 10px;
  width: 100%;
`;

const Title = styled.h1`
  text-align: center;
`;

const Content = styled.div`
  margin: 20px;
`;

const Cover = styled.div`
  width: 400px;
  background-color: white;
  border-radius: 6px;
`;

const Wrapper = styled.div`
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #1890ff;
  text-align: center;
`;

const ButtonStyle = styled(Button)`
  width: 100%;
`;

ForgotPasswordPage.propTypes = {};
