/**
 *
 * ResetPasswordPage
 *
 */

import React, { useState } from 'react';
// import PropTypes from 'prop-types';
// import { FormattedMessage } from 'react-intl';
import { useSelector, useDispatch } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import { useInjectReducer, useInjectSaga } from 'redux-injectors';
import { Button, notification } from 'antd';
import { Form, Input } from 'formik-antd';
import { Formik } from 'formik';
import styled from 'styled-components';
import { useHistory } from 'react-router-dom';
import axios from 'axios';
import makeSelectResetPasswordPage from './selectors';
import reducer from './reducer';
import saga from './saga';
// import messages from './messages';
import validationSchema from './Validation.Shema';

const stateSelector = createStructuredSelector({
  resetPasswordPage: makeSelectResetPasswordPage(),
});

const initialValues = {
  password: '',
  confirmPassword: '',
};

export default function ResetPasswordPage() {
  const history = useHistory();
  useInjectReducer({ key: 'resetPasswordPage', reducer });
  useInjectSaga({ key: 'resetPasswordPage', saga });

  /* eslint-disable no-unused-vars */
  const { resetPasswordPage } = useSelector(stateSelector);
  const dispatch = useDispatch();
  /* eslint-enable no-unused-vars */
  const [loading, setLoading] = useState(false);

  const onSubmit = async values => {
    try {
      setLoading(true);
      await axios.post(
        `http://5f34fe339124200016e193eb.mockapi.io/videoCall/Auth`,
        values,
      );
      notification.success({
        message: 'Done. Change password succeed',
      });
      history.push('/');
    } catch (e) {
      setLoading(true);
      notification.error({
        message: 'Error. Password reset failed',
      });
    }
  };

  return (
    <Wrapper>
      <Cover>
        <Content>
          <Title>New password</Title>
          <Formik
            initialValues={initialValues}
            onSubmit={onSubmit}
            validationSchema={validationSchema}
          >
            <Form>
              <Form.Item name="password" required>
                <InputStyle
                  type="password"
                  name="password"
                  autoFocus
                  placeholder="Enter your new password"
                />
              </Form.Item>
              <Form.Item name="confirmPassword" required>
                <InputStyle
                  type="password"
                  name="confirmPassword"
                  placeholder="Enter your new confirm password"
                />
              </Form.Item>
              <Button htmlType="submit" type="primary" block loading={loading}>
                Submit
              </Button>
            </Form>
          </Formik>
        </Content>
      </Cover>
    </Wrapper>
  );
}

const Title = styled.h1`
  text-align: center;
`;

const Content = styled.div`
  margin: 20px;
`;

const InputStyle = styled(Input)`
  padding: 10px;
  width: 100%;
`;

const Cover = styled.div`
  width: 400px;
  background-color: white;
  border-radius: 6px;
`;

const Wrapper = styled.div`
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #1890ff;
`;

ResetPasswordPage.propTypes = {};
