import React from 'react';
import { Button, Checkbox } from 'antd';
import { Link } from 'react-router-dom';
import styled from 'styled-components';
import { Formik } from 'formik';
import { Input, Form } from 'formik-antd';

import { login } from '../../services/Auth';
import validationSchema from './Validation.Schema';

const Wrapper = styled.div`
  background: #1890ff;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100vh;
`;

const Container = styled.div`
  background: white;
  min-width: 500px;
  padding: 50px;
  border-radius: 6px;

  @media only screen and (max-width: 600px) {
    min-width: 370px;
    padding: 40px 30px;
  }
`;

const TitleWrapper = styled.div`
  text-align: center;
`;

const TitleStyled = styled.h1`
  font-size: 32px;
  font-weight: 600;
  letter-spacing: 2px;
`;

const ButtonWrapper = styled.div`
  text-align: center;
`;

const ButtonStyled = styled(Button)`
  height: auto;
  font-size: 18px;
  font-weight: 600;
  letter-spacing: 2px;
`;

const InputStyled = styled(Input)`
  padding: 10px;
  width: 100%;
`;

const LinkWrapper = styled.div`
  display: flex;
  flex-direction: column;
  align-items: center;
  margin-top: 20px;
`;

export default function SignInPage() {
  const onSubmit = async values => {
    const email = values.Email;
    const password = values.Password;
    const { data } = await login(email, password);
    console.log('data', data);
  };

  return (
    <Wrapper>
      <Container>
        <TitleWrapper>
          <TitleStyled>Sign In</TitleStyled>
        </TitleWrapper>
        <Formik
          initialValues={initialValues}
          onSubmit={onSubmit}
          validationSchema={validationSchema}
        >
          <Form>
            <Form.Item name="Email" required>
              <InputStyled
                type="email"
                name="Email"
                autoFocus
                placeholder="Enter your email"
              />
            </Form.Item>

            <Form.Item name="Password" required>
              <InputStyled
                type="password"
                name="Password"
                placeholder="Enter your password"
              />
            </Form.Item>

            <Form.Item name="remember" valuePropName="checked">
              <Checkbox>Remember me</Checkbox>
            </Form.Item>
            <ButtonWrapper>
              <ButtonStyled type="primary" htmlType="submit">
                Sign In
              </ButtonStyled>
            </ButtonWrapper>

            <LinkWrapper>
              <Link to="/forgot-password">Forgot password?</Link>
              <Link to="/sign-up">Do not have an account?</Link>
            </LinkWrapper>
          </Form>
        </Formik>
      </Container>
    </Wrapper>
  );
}

const initialValues = {
  Email: '',
  Password: '',
};

SignInPage.propTypes = {};
