import React, { useState, useEffect, useMemo } from 'react';
import { Modal, Row, Col, Typography, Checkbox, Button } from 'antd';
import { Form, Input, Cascader, Select, Radio } from 'formik-antd';
import styled from 'styled-components';
import PropTypes from 'prop-types';
import { filter, sortBy } from 'lodash';
import { useFormikContext } from 'formik';

import {
  getCategory,
  getCitiesStripe,
  getAllLocation,
  generateName,
} from '../../services/Auth';

const { Option } = Select;

const InformationBusiness = props => {
  const { setValueCategory } = props;
  const { setFieldValue } = useFormikContext();

  const [firstName, setFirstName] = useState('');
  const [lastName, setLastName] = useState('');
  const [userName, setUserName] = useState('');
  const [openModal, setOpenModal] = useState(false);
  const [optionsCategory, setOptionsCategory] = useState([]);
  const [optionCitiesStripe, setOptionCitiesStripe] = useState([]);
  const [optionAllStates, setOptionAllStates] = useState([]);
  const [checked, setChecked] = useState(false);

  useEffect(() => {
    const fetchDataCategory = async () => {
      const { data } = await getCategory();
      setOptionsCategory(data.categories);
    };
    fetchDataCategory();

    const fetchDataCitiesStripe = async () => {
      const { data } = await getCitiesStripe();
      setOptionCitiesStripe(data.cities || []);
    };
    fetchDataCitiesStripe();

    const fetchDataAllCity = async () => {
      const { data } = await getAllLocation();
      setOptionAllStates(data);
    };
    fetchDataAllCity();
  }, []);

  const handleChangeBilling = () => {
    if (checked) {
      setOpenModal(false);
      setChecked(false);
    } else {
      setOpenModal(true);
      setChecked(true);
    }
  };

  const onClickButtonModal = () => {
    setOpenModal(false);
  };

  const activeField = async () => {
    const combindData = (firstName + lastName)
      .normalize('NFD')
      .replace(/[\u0300-\u036f]/g, '')
      .replace(/đ/g, 'd')
      .replace(/Đ/g, 'D')
      .toLowerCase();
    const { data } = await generateName(combindData);
    setUserName(data.userName);
    setFieldValue('userName', data.userName);
  };

  const convertDataCategory = useMemo(
    () => optionsCategory.filter(item => item.type === 'enterprise'),
    [optionsCategory],
  );

  const onSelectCategory = value => {
    const arr = filter(optionsCategory, item => item.name === value[0]);
    let result = [];
    if (value.length > 0) {
      result.push(...filter(arr[0].subcategories, it => it.name === value[1]));
    }
    if (value.length === 3) {
      result = filter(result[0].subcategories, it => it.name === value[2]);
    }
    setValueCategory(result);
  };

  const convertData = useMemo(() => sortBy(optionCitiesStripe, ['name']), [
    optionCitiesStripe,
  ]);

  const makeDataState = dataState => {
    const state = dataState.filter(item => item.country === 'U.S.A.');
    return sortBy(state, ['state']);
  };

  const convertState = useMemo(() => makeDataState(optionAllStates), [
    optionAllStates,
  ]);

  const onChange = e => {
    if (e.target.value === 1) {
      setFieldValue('publicSchool', true);
      setFieldValue('nonProfit', false);
      setFieldValue('theater', false);
      setFieldValue('notApplicable', false);
    } else if (e.target.value === 3) {
      setFieldValue('publicSchool', false);
      setFieldValue('theater', false);
      setFieldValue('notApplicable', false);
      setFieldValue('nonProfit', true);
    } else if (e.target.value === 2) {
      setFieldValue('publicSchool', false);
      setFieldValue('nonProfit', false);
      setFieldValue('notApplicable', false);
      setFieldValue('theater', true);
    } else if (e.target.value === 4) {
      setFieldValue('publicSchool', false);
      setFieldValue('nonProfit', false);
      setFieldValue('theater', false);
      setFieldValue('notApplicable', true);
    }
  };

  return (
    <>
      <RowStyle>
        <LeftWrapper sm={23} md={11}>
          <FormContainer>
            <InputLabel>Company Name</InputLabel>
            <FormItem name="companyName" required>
              <InputStyle
                type="text"
                size="large"
                autoFocus
                placeholder="Company Name"
                name="companyName"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>First Name</InputLabel>
            <FormItem name="firstName" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="First Name"
                name="firstName"
                onChange={e => setFirstName(e.target.value)}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Last Name</InputLabel>
            <FormItem name="lastName" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Last Name"
                name="lastName"
                onChange={e => setLastName(e.target.value)}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Job Title</InputLabel>
            <FormItem name="title" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Title"
                name="title"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Company Website</InputLabel>
            <FormItem name="companyWebsite" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Website"
                name="companyWebsite"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Company Nickname</InputLabel>
            <FormItem name="userName" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Profile Nickname"
                name="userName"
                defaultValue={userName}
                onFocus={activeField}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Employees</InputLabel>
            <FormItem name="numberOfFullTimeEmployees" required>
              <SelectStyle
                name="numberOfFullTimeEmployees"
                size="large"
                defaultValue="1-2"
              >
                <Option value="1-2">1-2</Option>
                <Option value="3-9">3-9</Option>
                <Option value="10+">10+</Option>
              </SelectStyle>
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Are you one of these ?</InputLabel>
            <RadioGroupContainer
              name="radiogroup"
              defaultValue={4}
              onChange={onChange}
            >
              <Col span={12}>
                <FormItem name="publicSchool">
                  <Radio value={1} name="publicSchool">
                    Public School
                  </Radio>
                </FormItem>
                <FormItem name="nonProfit">
                  <Radio value={3} name="nonProfit">
                    Non-Profit
                  </Radio>
                </FormItem>
              </Col>
              <Col span={12}>
                <FormItem name="theater">
                  <Radio value={2} name="theater">
                    Theater
                  </Radio>
                </FormItem>
                <FormItem name="notApplicable">
                  <Radio value={4} name="notApplicable">
                    Not Applicable
                  </Radio>
                </FormItem>
              </Col>
            </RadioGroupContainer>
          </FormContainer>
          <FormContainer>
            <InputLabel>Category</InputLabel>
            <FormItem name="categories" required>
              <CascaderStyle
                name="categories"
                size="large"
                options={convertDataCategory}
                allowClear
                onChange={onSelectCategory}
                fieldNames={{
                  label: 'name',
                  value: 'name',
                  children: 'subcategories',
                }}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>City</InputLabel>
            <FormItem name="cityStripe">
              <SelectStyle
                name="cityStripe"
                size="large"
                placeholder="Please select"
                allowClear
              >
                {convertData.map((item, index) => (
                  <Option key={index} value={JSON.stringify(item)}>
                    {item.name}
                  </Option>
                ))}
              </SelectStyle>
            </FormItem>
          </FormContainer>
          <TextStyle style={{ display: 'block' }}>
            After sign up is complete, you may add more cities and job
            categories to your profile
          </TextStyle>
        </LeftWrapper>
        <RightWrapper sm={23} md={11}>
          <CheckboxStyle
            name="checkBill"
            checked={checked}
            onChange={handleChangeBilling}
          >
            <span style={{ fontSize: '16px' }}>
              &nbsp;Billing address is different
            </span>
          </CheckboxStyle>
          <FormContainer>
            <InputLabel>Company Address</InputLabel>
            <FormItem name="address" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Street address"
                name="address"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Unit/Apt</InputLabel>
            <FormItem name="unit">
              <InputStyle
                type="text"
                size="large"
                placeholder="Unit/Apt"
                name="unit"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>City</InputLabel>
            <FormItem name="city" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="City"
                name="city"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>State</InputLabel>
            <FormItem name="state">
              <SelectStyle
                name="state"
                size="large"
                placeholder="Please select"
                allowClear
              >
                {convertState.map((item, index) => (
                  <Option key={index} value={JSON.stringify(item)}>
                    {item.state}
                  </Option>
                ))}
              </SelectStyle>
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Zip Code</InputLabel>
            <FormItem name="zipCode" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Zip"
                name="zipCode"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Company Phone number</InputLabel>
            <FormItem name="companyPhoneNumber" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Phone"
                name="companyPhoneNumber"
              />
            </FormItem>
          </FormContainer>
          <TextStyle style={{ display: 'block' }}>
            New accounts receive 30 days free trial no charge will be made
            today. Can cancel any time.
          </TextStyle>
        </RightWrapper>
      </RowStyle>
      <ModalStyle
        onCancel={() => {
          setOpenModal(!openModal);
        }}
        visible={openModal}
        footer={null}
        closable={false}
        centered
        bodyStyle={{ padding: '30px', textAlign: 'center' }}
      >
        <TitleModal>Billing address is different</TitleModal>
        <ContainerModal>
          <Col>
            <FormItem name="addressDifferent">
              <InputStyle
                name="addressDifferent"
                type="text"
                size="large"
                placeholder="Address"
              />
            </FormItem>
            <FormItem name="unitDifferent">
              <InputStyle
                name="unitDifferent"
                type="text"
                size="large"
                placeholder="Unit/Apt"
              />
            </FormItem>
            <FormItem name="cityDifferent">
              <InputStyle
                name="cityDifferent"
                type="text"
                size="large"
                placeholder="City"
              />
            </FormItem>
          </Col>
          <Col>
            <FormItem name="stateDifferent">
              <InputStyle
                name="stateDifferent"
                type="text"
                size="large"
                placeholder="State"
              />
            </FormItem>
            <FormItem name="zipCodeDifferent">
              <InputStyle
                name="zipCodeDifferent"
                type="text"
                size="large"
                placeholder="Zip Code"
              />
            </FormItem>
            <FormItem name="phoneDifferent">
              <InputStyle
                name="phoneDifferent"
                type="text"
                size="large"
                placeholder="Phone"
              />
            </FormItem>
          </Col>
        </ContainerModal>
        <Button type="primary" shape="round" onClick={onClickButtonModal}>
          OK
        </Button>
      </ModalStyle>
    </>
  );
};

InformationBusiness.propTypes = {
  setValueCategory: PropTypes.any,
};

const RowStyle = styled(Row)`
  justify-content: space-between;
  height: 65vh;
  overflow-y: scroll;

  .ant-form-item-label > label {
    font-size: 16px;
  }
`;

const LeftWrapper = styled(Col)`
  text-align: left;
  padding-right: 5px;
  padding-left: 10px;

  .ant-form-item-explain {
    font-size: 12px;
  }
`;

const RightWrapper = styled(Col)`
  text-align: left;
  padding-left: 5px;
  padding-right: 10px;

  .ant-form-item-explain {
    font-size: 12px;
  }
`;

const InputStyle = styled(Input)`
  display: block;

  .ant-form-item-control-input {
    min-height: 0;
  }
`;

const SelectStyle = styled(Select)`
  width: 50%;
  font-size: 16px;
`;

const RadioGroupContainer = styled(Radio.Group)`
  width: 100%;
  display: flex;
  span {
    font-size: 14px;
    font-weight: 600;
    margin-bottom: 0;
    line-height: normal;
    font-family: Roboto, sans-serif;
    color: #666666;
  }
  .ant-form label {
    margin-bottom: 10px;
  }
`;
const TextStyle = styled(Typography)`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
`;

const CheckboxStyle = styled(Checkbox)`
  text-align: left;
  padding: 6px 0 33px;
  color: #666666;
  font-size: 14px;
  font-weight: 600;
  margin-bottom: 0;
  line-height: normal;
  font-family: Roboto, sans-serif;
  margin-left: 5px;
  margin-top: 15px;
`;

const ModalStyle = styled(Modal)`
  .ant-modal-content {
    border-radius: 8px;
  }
`;

const ContainerModal = styled(Row)`
  justify-content: space-around;
  padding-top: 20px;
`;

const TitleModal = styled.span`
  font-size: 18px;
  text-align: center;
`;

const CascaderStyle = styled(Cascader)`
  font-size: 16px;
`;

const FormContainer = styled(Row)`
  margin-bottom: 20px;
  text-align: left;
`;

const InputLabel = styled.p`
  color: #666666;
  width: 100%;
  font-family: 'Titillium Web', sans-serif;
  font-size: 15px;
  font-weight: 600;
  margin-bottom: 10px;
`;

const FormItem = styled(Form.Item)`
  flex: 1;
  margin-bottom: 0;
`;

export default InformationBusiness;
