import React, { useState, useEffect, useMemo } from 'react';
import { Row, Col, Typography } from 'antd';
import { Form, Input, Cascader, Select } from 'formik-antd';
import styled from 'styled-components';
import PropTypes from 'prop-types';
import { filter, sortBy } from 'lodash';
import { useFormikContext } from 'formik';

import {
  getCitiesStripe,
  getAllLocation,
  getCategory,
  generateName,
} from '../../services/Auth';

const { Option } = Select;

const InformationPeople = props => {
  const { setFieldValue } = useFormikContext();
  const { setValueCategory } = props;

  const [optionsCategory, setOptionsCategory] = useState([]);
  const [firstName, setFirstName] = useState('');
  const [lastName, setLastName] = useState('');
  const [optionCitiesStripe, setOptionCitiesStripe] = useState([]);
  const [optionAllStates, setOptionAllStates] = useState([]);
  const [userName, setUserName] = useState('');

  useEffect(() => {
    const fetchDataCategory = async () => {
      const { data } = await getCategory();
      setOptionsCategory(data.categories);
    };
    fetchDataCategory();

    const fetchDataCitiesStripe = async () => {
      const { data } = await getCitiesStripe();
      setOptionCitiesStripe(data.cities || []);
    };
    fetchDataCitiesStripe();

    const fetchAllLocation = async () => {
      const { data } = await getAllLocation();
      setOptionAllStates(data);
    };
    fetchAllLocation();
  }, []);

  const activateField = async () => {
    const combindData = (firstName + lastName)
      .normalize('NFD')
      .replace(/[\u0300-\u036f]/g, '')
      .replace(/đ/g, 'd')
      .replace(/Đ/g, 'D')
      .toLowerCase();
    const { data } = await generateName(combindData);
    setUserName(data.userName);
    setFieldValue('userName', data.userName);
  };

  const convertDataCategory = useMemo(
    () => optionsCategory.filter(item => item.type === 'individual'),
    [optionsCategory],
  );

  const onSelectCategory = value => {
    const arr = filter(optionsCategory, item => item.name === value[0]);
    let result = [];
    if (value.length > 0) {
      result.push(...filter(arr[0].subcategories, it => it.name === value[1]));
    }
    if (value.length === 3) {
      result = filter(result[0].subcategories, it => it.name === value[2]);
    }
    setValueCategory(result);
  };

  const convertData = useMemo(() => sortBy(optionCitiesStripe, ['name']), [
    optionCitiesStripe,
  ]);

  const makeDataState = dataState => {
    const state = dataState.filter(item => item.country === 'U.S.A.');
    return sortBy(state, ['state']);
  };

  const convertState = useMemo(() => makeDataState(optionAllStates), [
    optionAllStates,
  ]);

  return (
    <>
      <RowStyle>
        <LeftWrapper sm={23} md={11}>
          <FormContainer>
            <InputLabel>First Name</InputLabel>
            <FormItem name="firstName" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="First Name"
                name="firstName"
                autoFocus
                onChange={e => setFirstName(e.target.value)}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Last Name</InputLabel>
            <FormItem name="lastName" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Last Name"
                name="lastName"
                onChange={e => setLastName(e.target.value)}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Nickname</InputLabel>
            <FormItem name="userName" required>
              <InputStyle
                name="userName"
                type="text"
                size="large"
                placeholder="Profile Nickname"
                defaultValue={userName}
                onFocus={activateField}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Job Category</InputLabel>
            <FormItem name="categories">
              <CascaderStyle
                name="categories"
                size="large"
                options={convertDataCategory}
                allowClear
                onChange={onSelectCategory}
                fieldNames={{
                  label: 'name',
                  value: 'name',
                  children: 'subcategories',
                }}
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>City</InputLabel>
            <FormItem name="cityStripe">
              <SelectStyle
                name="cityStripe"
                size="large"
                placeholder="Please select"
                allowClear
              >
                {convertData.map((item, index) => (
                  <Option key={index} value={JSON.stringify(item)}>
                    {item.name}
                  </Option>
                ))}
              </SelectStyle>
            </FormItem>
          </FormContainer>
          <TextStyle>
            After sign up is complete, you may add more cities and job
            categories to your profile
          </TextStyle>
        </LeftWrapper>

        <RightWrapper sm={23} md={11}>
          <FormContainer>
            <InputLabel>Billing street address</InputLabel>
            <FormItem name="address" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Billing street address"
                name="address"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Unit/Apt</InputLabel>
            <FormItem name="unit">
              <InputStyle
                type="text"
                size="large"
                placeholder="Unit/Apt"
                name="unit"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>City</InputLabel>
            <FormItem name="city" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="City"
                name="city"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>State</InputLabel>
            <FormItem name="state">
              <SelectStyle
                name="state"
                size="large"
                placeholder="Please select"
                allowClear
              >
                {convertState.map((item, index) => (
                  <Option key={index} value={JSON.stringify(item)}>
                    {item.state}
                  </Option>
                ))}
              </SelectStyle>
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Zip Code</InputLabel>
            <FormItem name="zipCode" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Zip"
                name="zipCode"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Phone number</InputLabel>
            <FormItem name="phone" required>
              <InputStyle
                type="text"
                size="large"
                placeholder="Phone"
                name="phone"
              />
            </FormItem>
          </FormContainer>
          <TextStyle>
            New accounts receive 30 days free trial no charge will be made
            today. Can cancel any time.
          </TextStyle>
        </RightWrapper>
      </RowStyle>
      {/* </FormStyle> */}
    </>
  );
};

InformationPeople.propTypes = {
  setValueCategory: PropTypes.any,
};

const RowStyle = styled(Row)`
  justify-content: space-between;

  .ant-form-item-label > label {
    font-size: 16px;
  }
`;

const LeftWrapper = styled(Col)`
  text-align: left;
  padding-right: 5px;
  padding-left: 10px;

  .ant-form-item-explain {
    font-size: 12px;
  }
`;

const RightWrapper = styled(Col)`
  text-align: left;
  padding-left: 5px;
  padding-right: 10px;

  .ant-form-item-explain {
    font-size: 12px;
  }
`;

const InputStyle = styled(Input)`
  display: block;

  .ant-form-item-control-input {
    min-height: 0;
  }
`;

const CascaderStyle = styled(Cascader)`
  font-size: 16px;
`;

const SelectStyle = styled(Select)`
  width: 50%;
  font-size: 16px;
`;

const TextStyle = styled(Typography)`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
`;

const FormContainer = styled(Row)`
  margin-bottom: 20px;
  text-align: left;
`;

const InputLabel = styled.p`
  color: #666666;
  width: 100%;
  font-family: 'Titillium Web', sans-serif;
  font-size: 15px;
  font-weight: 600;
  margin-bottom: 10px;
`;

const FormItem = styled(Form.Item)`
  flex: 1;
  margin-bottom: 0;
`;

export default InformationPeople;
