import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { loadStripe } from '@stripe/stripe-js';
import { Input, Button, Checkbox } from 'antd';
import {
  CardNumberElement,
  Elements,
  CardExpiryElement,
  CardCvcElement,
  useElements,
  useStripe,
} from '@stripe/react-stripe-js';
import PropTypes from 'prop-types';
import axios from '../../axios';
import { STRIPE_PULIC_KEY } from '../../config';

const stripePromise = loadStripe(STRIPE_PULIC_KEY);
// styled css
const FormCardNumberStyle = styled.form`
  .StripeElement {
    box-sizing: border-box;
    height: 40px;
    padding: 10px 12px;
    border: 1px solid transparent;
    border-radius: 4px;
    background-color: white;

    box-shadow: 0 1px 3px 0 #e6ebf1;
    -webkit-transition: box-shadow 150ms ease;
    transition: box-shadow 150ms ease;
  }

  .StripeElement--focus {
    box-shadow: 0 1px 3px 0 #cfd7df;
  }

  .StripeElement--invalid {
    border-color: #fa755a;
  }

  .StripeElement--webkit-autofill {
    background-color: #fefde5 !important;
  }
`;

const FormCardExpiryStyle = styled.form`
  .StripeElement {
    width: 180px;
    margin-right: 20px;
    box-sizing: border-box;
    height: 40px;
    padding: 10px 12px;
    border: 1px solid transparent;
    border-radius: 4px;
    background-color: white;

    box-shadow: 0 1px 3px 0 #e6ebf1;
    -webkit-transition: box-shadow 150ms ease;
    transition: box-shadow 150ms ease;
  }

  .StripeElement--focus {
    box-shadow: 0 1px 3px 0 #cfd7df;
  }

  .StripeElement--invalid {
    border-color: #fa755a;
  }

  .StripeElement--webkit-autofill {
    background-color: #fefde5 !important;
  }
`;

const FormCardCvcStyle = styled.form`
  .StripeElement {
    width: 80px;
    box-sizing: border-box;
    height: 40px;
    padding: 10px 12px;
    border: 1px solid transparent;
    border-radius: 4px;
    background-color: white;

    box-shadow: 0 1px 3px 0 #e6ebf1;
    -webkit-transition: box-shadow 150ms ease;
    transition: box-shadow 150ms ease;
  }

  .StripeElement--focus {
    box-shadow: 0 1px 3px 0 #cfd7df;
  }

  .StripeElement--invalid {
    border-color: #fa755a;
  }

  .StripeElement--webkit-autofill {
    background-color: #fefde5 !important;
  }
`;

const Wrapper = styled.div`
  padding: 0 20px;
  display: flex;
  justify-content: space-between;

  @media only screen and (max-width: 600px) {
    display: block;
  }
`;

const LeftWrapper = styled.div`
  width: 45%;
  padding-right: 10px;

  @media only screen and (max-width: 600px) {
    width: 100%;
    padding-right: 0;
  }
`;

const LeftInner = styled.div`
  padding-top: 20px;
  display: flex;
  justify-content: space-between;
`;

const RightWrapper = styled.div`
  width: 45%;
  padding-left: 10px;

  @media only screen and (max-width: 600px) {
    width: 100%;
    padding-top: 10px;
  }
`;

const SubscriptionValueStyled = styled.div`
  display: flex;
  justify-content: space-between;
`;

const TextSubscriptionStyled = styled.span`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
`;

const PromoCodeWrapper = styled.div`
  padding-top: 30px;
  border-bottom: 1px solid #aab7c4;
  text-align: left;
`;

const TextPromoStyled = styled.span`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
  cursor: pointer;
`;

const PromoCodeStyled = styled.div`
  display: flex;
  margin-bottom: 10px;
  justify-content: space-between;
  align-items: center;
`;

const TotalPriceWrapper = styled.div`
  padding-top: 20px;
  display: flex;
  justify-content: space-between;
  padding-bottom: 150px;
`;

const CheckBoxStyled = styled(Checkbox)`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
  padding-bottom: 50px;
`;

const InputStyle = styled(Input)`
  width: 70%;
  border-radius: 4px;

  .ant-form-item-control-input {
    min-height: 0;
  }
`;

const ButtonStyle = styled(Button)`
  padding: 10px 20px;
  display: flex;
  align-items: center;
`;

const TextAmount = styled.span`
  line-height: 1.7;
  color: #666666;
  font-size: 14px;
  font-family: Roboto, sans-serif;
  padding-bottom: 50px;
  font-weight: 600;
`;

const CARD_ELEMENT_OPTIONS = {
  style: {
    base: {
      color: '#32325d',
      fontFamily: '"Helvetica Neue", Helvetica, sans-serif',
      fontSmoothing: 'antialiased',
      fontSize: '16px',
      '::placeholder': {
        color: '#aab7c4',
      },
    },
    invalid: {
      color: '#fa755a',
      iconColor: '#fa755a',
    },
  },
};

const CheckoutForm = props => {
  const [error, setError] = useState(null);
  const [errorCoupon, setErrorCoupon] = useState(null);
  const [showPromoCode, setShowPromoCode] = useState(false);
  const [showTextPromo, setShowTextPromo] = useState(true);
  const [totalBill, setTotalBill] = useState(props.price);
  const [code, setCode] = useState(null);
  const stripe = useStripe();
  const elements = useElements();
  const { isFinish, onSubmitPayment, citiStripe } = props;

  const onClick = () => {
    setShowPromoCode(true);
    setShowTextPromo(false);
  };

  const checkCoupon = async () => {
    if (!code) {
      return;
    }
    try {
      const { data } = await axios.post('/subscription/check-promo', {
        code,
      });
      let total = totalBill;
      if (data.percent_off) {
        total = (data.percent_off * totalBill) / 100;
      } else {
        total = totalBill - data.amount_off;
      }
      setTotalBill(total);
      onSubmitPayment({ couponCode: code });
    } catch (e) {
      setErrorCoupon(e);
    }
  };

  const handleChange = event => {
    if (event.error) {
      setError(event.error.message);
    } else {
      setError(null);
    }
  };

  useEffect(() => {
    if (isFinish) {
      if (citiStripe.name !== 'New York City') {
        onSubmitPayment({ stripeToken: null });
        return;
      }
      const handleSubmit = async () => {
        const card = elements.getElement(CardNumberElement);
        const result = await stripe.createToken(card);
        if (result.error) {
          setError(result.error.message);
        } else {
          setError(null);
          onSubmitPayment({ stripeToken: result.token.id });
        }
      };
      handleSubmit();
    }
  }, [isFinish, citiStripe]);

  return (
    <Wrapper>
      <LeftWrapper>
        <FormCardNumberStyle>
          <CardNumberElement
            id="card-number-element"
            options={CARD_ELEMENT_OPTIONS}
            onChange={handleChange}
          />
        </FormCardNumberStyle>

        <LeftInner>
          <FormCardExpiryStyle>
            <CardExpiryElement
              id="card-expiry-Element"
              options={CARD_ELEMENT_OPTIONS}
              onChange={handleChange}
            />
          </FormCardExpiryStyle>
          <FormCardCvcStyle>
            <CardCvcElement
              id="card-cvc-element"
              options={CARD_ELEMENT_OPTIONS}
              onChange={handleChange}
            />
          </FormCardCvcStyle>
        </LeftInner>
        <div className="card-errors" role="alert">
          <span style={{ color: '#FA765A' }}>{error}</span>
        </div>
      </LeftWrapper>

      <RightWrapper>
        <SubscriptionValueStyled>
          <TextSubscriptionStyled>
            {/* Subscription Value - {typeAccount} */}
          </TextSubscriptionStyled>
          <TextAmount>${totalBill}</TextAmount>
        </SubscriptionValueStyled>
        <PromoCodeWrapper>
          {showTextPromo ? (
            <TextPromoStyled onClick={onClick}>
              Do you have promo code?
            </TextPromoStyled>
          ) : null}

          {showPromoCode ? (
            <PromoCodeStyled>
              <InputStyle
                type="text"
                placeholder="Promo code"
                size="large"
                onChange={e => setCode(e.target.value)}
              />
              <ButtonStyle
                type="primary"
                shape="round"
                size={40}
                onClick={checkCoupon}
              >
                Add
              </ButtonStyle>
            </PromoCodeStyled>
          ) : null}
          <div className="card-errors" role="alert">
            <span style={{ color: '#FA765A' }}>{errorCoupon}</span>
          </div>
        </PromoCodeWrapper>

        <TotalPriceWrapper>
          <TextSubscriptionStyled>
            Total monthly fee after 30 day trial -
          </TextSubscriptionStyled>
          <TextAmount>${totalBill}</TextAmount>
        </TotalPriceWrapper>

        <CheckBoxStyled name="checkbox">
          <span>
            &nbsp;I agree to a monthly automatic payment after my free trial
            expires
          </span>
        </CheckBoxStyled>
      </RightWrapper>
    </Wrapper>
  );
};

const Payment = props => {
  const { isFinish, onSubmitPayment, price, citiStripe } = props;
  return (
    <Elements stripe={stripePromise}>
      <CheckoutForm
        isFinish={isFinish}
        onSubmitPayment={onSubmitPayment}
        price={price}
        citiStripe={citiStripe}
      />
    </Elements>
  );
};

Payment.propTypes = {
  isFinish: PropTypes.number,
  onSubmitPayment: PropTypes.func,
  price: PropTypes.number,
  citiStripe: PropTypes.any,
};

CheckoutForm.propTypes = {
  isFinish: PropTypes.number,
  onSubmitPayment: PropTypes.func,
  price: PropTypes.number,
  citiStripe: PropTypes.any,
};

export default Payment;
