import React, { useEffect, useState } from 'react';
import styled from 'styled-components';
import { Input, Form, Radio, Select } from 'formik-antd';
import { Row, Col, Divider } from 'antd';
import { Field } from 'formik';
import PropTypes from 'prop-types';

import PeopleImage from '../../images/type-account/people.png';
import BusinessImage from '../../images/type-account/business.png';

const SetUpAccount = props => {
  const { type, onSelectType } = props;

  const [chooseImageBusiness, setChooseImageBusiness] = useState(true);
  const [chooseImagePeople, setChooseImagePeople] = useState(false);
  const [value, setValue] = useState(null);

  useEffect(() => {
    setValue(type);
  }, [type]);

  useEffect(() => {
    if (value === 'Business') {
      setChooseImageBusiness(true);
      setChooseImagePeople(false);
    } else {
      setChooseImageBusiness(false);
      setChooseImagePeople(true);
    }
  }, [value]);

  const onClickImage = e => {
    setValue(e.target.value);
    onSelectType(e.target.value);
  };

  const onChange = () => {};

  // const handleSelect = e => {
  //   console.log(e);
  // };

  return (
    <Wrapper>
      <Row>
        <Col span={12} style={{ paddingRight: 30 }}>
          <FormContainer>
            <InputLabel>Email</InputLabel>
            <FormItem name="email" required labelCol={{ span: 6 }}>
              <InputStyled name="email" placeholder="Email" autoFocus />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <CheckBoxWrapper>
              <FormItem name="keepMe" labelAlign="left">
                <CheckBoxInner onChange={onChange}>
                  <Field
                    type="checkbox"
                    name="keepMe"
                    label="Keep me signed in"
                  />
                  <CheckBoxStyled htmlFor="keepMe">
                    Keep me signed in
                  </CheckBoxStyled>
                </CheckBoxInner>
              </FormItem>
              <FormItem name="termsOfService">
                <CheckBoxInner onChange={onChange}>
                  <Field type="checkbox" name="termsOfService" />
                  <CheckBoxStyled htmlFor="termsOfService">
                    You must agree to{' '}
                    <a
                      href="https://app.termly.io/document/terms-of-use-for-saas/8204968b-63d9-471a-ab0c-675244814e55"
                      target="_blank"
                    >
                      terms of service
                    </a>
                  </CheckBoxStyled>
                </CheckBoxInner>
              </FormItem>
              <FormItem name="communityGuidelines">
                <CheckBoxInner onChange={onChange}>
                  <Field type="checkbox" name="communityGuidelines" />
                  <CheckBoxStyled htmlFor="communityGuidelines">
                    Agree to Community Guidelines
                  </CheckBoxStyled>
                </CheckBoxInner>
              </FormItem>
              <FormItem name="profileVisibility">
                <FieldProfileVisibility
                  size="large"
                  defaultValue=""
                  name="profileVisibility"
                >
                  <OptionStyled value="">
                    Choose Profile Visibility
                  </OptionStyled>
                  <OptionStyled value="only-member">
                    Visible only for members
                  </OptionStyled>
                  <OptionStyled value="no-one">No one can see</OptionStyled>
                  <OptionStyled value="everyone">
                    Visible to everyone
                  </OptionStyled>
                </FieldProfileVisibility>
              </FormItem>
            </CheckBoxWrapper>
          </FormContainer>
        </Col>
        <Col span={12} style={{ paddingLeft: 30 }}>
          <FormContainer>
            <InputLabel>Password</InputLabel>
            <FormItem name="password" required labelCol={{ span: 6 }}>
              <InputStyled
                type="password"
                name="password"
                placeholder="Password"
              />
            </FormItem>
          </FormContainer>
          <FormContainer>
            <InputLabel>Confirm Password</InputLabel>
            <FormItem name="confirmPassword" required labelCol={{ span: 6 }}>
              <InputStyled
                type="password"
                name="confirmPassword"
                placeholder="Confirm Password"
              />
            </FormItem>
          </FormContainer>
        </Col>
      </Row>
      <Divider style={{ margin: 0 }}>
        <FormItem name="typeAccount" required>
          <Radio.Group name="typeAccount" onChange={onClickImage} value={value}>
            <RadioCustom value="Business">
              <BoxImageStyled
                style={{ opacity: `${chooseImageBusiness ? '1' : '0.5'}` }}
              >
                <ImageStyled src={BusinessImage} alt="business" />
              </BoxImageStyled>
              <InputLabel>This is business</InputLabel>
            </RadioCustom>
            <RadioCustom value="Freelancer">
              <BoxImageStyled
                style={{ opacity: `${chooseImagePeople ? '1' : '0.5'}` }}
              >
                <ImageStyled src={PeopleImage} alt="people" />
              </BoxImageStyled>
              <InputLabel>I am freelancer</InputLabel>
            </RadioCustom>
          </Radio.Group>
        </FormItem>
      </Divider>
    </Wrapper>
  );
};

SetUpAccount.propTypes = {
  type: PropTypes.string,
  onSelectType: PropTypes.func,
};
const Wrapper = styled.div`
  .ant-form-item {
    width: 100%;
  }

  @media only screen and (max-width: 600px) {
    padding: 0 20px;
  }
`;

const BoxImageStyled = styled.div`
  width: 120px;
  margin: 10px 20px;
  display: flex;
  align-items: center;
  justify-content: center;
  cursor: pointer;

  @media only screen and (max-width: 600px) {
    width: 90px;
  }
`;

const ImageStyled = styled.img`
  width: 100px;
  height: auto;
`;

const CheckBoxWrapper = styled.div`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  text-align: left;
  width: 100%;
  .ant-form-item-control-input-content {
    flex: unset;
  }

  .ant-form-item {
    margin-bottom: 0;
  }
`;

const CheckBoxInner = styled.div`
  display: flex;
  align-items: center;
`;

const CheckBoxStyled = styled.label`
  margin-left: 10px;
  letter-spacing: 0.5px;
  font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
  color: rgba(102, 102, 102, 0.7);
  font-size: 14px;
  font-weight: 400;
  margin-bottom: 0;
  line-height: normal;
  a {
    text-decoration: underline;
    cursor: pointer;
    color: #666666;
  }
`;

const InputLabel = styled.p`
  color: #666666;
  width: 100%;
  font-family: 'Titillium Web', sans-serif;
  font-size: 15px;
  font-weight: 600;
  margin-bottom: 10px;
`;

const FormContainer = styled(Row)`
  margin-bottom: 20px;
  text-align: left;
`;

const InputStyled = styled(Input)`
  padding: 10px;
  width: 100%;
`;

const RadioCustom = styled(Radio)`
  .ant-radio {
    .ant-radio-inner {
      display: none;
    }
  }
`;

const FormItem = styled(Form.Item)`
  flex: 1;
  .ant-form-item-control-input-content {
    width: 100%;
  }
`;
const OptionStyled = styled.option`
  width: max-content;
`;
const FieldProfileVisibility = styled(Select)`
  text-align: left;
  margin-top: 10px;
`;

export default SetUpAccount;
