import * as Yup from 'yup';
const phoneRegExp = /^\(?([0-9]{3})\)?[-. ]?([0-9]{3})[-. ]?([0-9]{4})$/;
const userNameRegExp = /^[A-Za-z0-9_-]+$/;

const validateSetUpAccount = Yup.object().shape({
  email: Yup.string()
    .email()
    .trim()
    .nullable()
    .required('Email is a required field'),
  password: Yup.string()
    .trim()
    .nullable()
    .min(8)
    .required('Password  is a required field'),
  confirmPassword: Yup.string()
    .trim()
    .nullable()
    .oneOf([Yup.ref('password'), null], 'Passwords must match')
    .required('Confirm password is a required field'),
  termsOfService: Yup.bool().oneOf([true], 'Please agree to Terms of Service'),
  communityGuidelines: Yup.bool().oneOf(
    [true],
    'Please agree to  Community Guideline',
  ),
  profileVisibility: Yup.string()
    .trim()
    .nullable()
    .required(' Please choose profile visibility'),
});
const validateBusinessForm = Yup.object().shape({
  companyName: Yup.string()
    .trim()
    .nullable()
    .required('Company name is a required filed'),
  firstName: Yup.string()
    .trim()
    .nullable()
    .required('First name is a required filed'),
  lastName: Yup.string()
    .trim()
    .nullable()
    .required('Last name is a required filed'),
  title: Yup.string()
    .trim()
    .nullable()
    .required('Title is a required filed'),
  companyWebsite: Yup.string()
    .trim()
    .nullable()
    .required('Website is a required filed'),
  userName: Yup.string()
    .trim()
    .nullable()
    .required('Nick name is a required filed')
    .matches(
      userNameRegExp,
      'User name must use only letters, numbers, underscores and dashes.',
    ),
  categories: Yup.array()
    .required('Select category is a required filed')
    .min(1)
    .max(3)
    .nullable(),
  cityStripe: Yup.string().required('Select city is a required filed'),
  address: Yup.string()
    .trim()
    .nullable()
    .required('Address is a required filed'),
  city: Yup.string()
    .trim()
    .nullable()
    .required('City is a required filed'),
  state: Yup.string().required('Select state is a required filed'),
  zipCode: Yup.string()
    .trim()
    .nullable()
    .required('Zip is a required filed'),
  companyPhoneNumber: Yup.string()
    .trim()
    .nullable()
    .matches(phoneRegExp, 'Phone number is not valid')
    .required('Phone is a required filed'),
});

const validateFreelancerForm = Yup.object().shape({
  firstName: Yup.string()
    .trim()
    .nullable()
    .required('First name is a required field'),
  lastName: Yup.string()
    .trim()
    .nullable()
    .required('Last name is a required field'),
  userName: Yup.string()
    .trim()
    .nullable()
    .required('Nick name is a required field')
    .matches(
      userNameRegExp,
      'User name must use only letters, numbers, underscores and dashes.',
    ),
  categories: Yup.array()
    .required('Select category is a required filed')
    .min(1)
    .max(3)
    .nullable(),
  cityStripe: Yup.string().required('Select city is a required filed'),
  address: Yup.string()
    .trim()
    .nullable()
    .required('Address is a required filed'),
  city: Yup.string()
    .trim()
    .nullable()
    .required('City is a required filed'),
  state: Yup.string().required('Select state is a required filed'),
  zipCode: Yup.string()
    .trim()
    .nullable()
    .required('Zip is a required filed'),
  phone: Yup.string()
    .trim()
    .nullable()
    .matches(phoneRegExp, 'Phone number is not valid')
    .required('Phone is a required filed'),
});

const validationSchema = (current, typeAcct) => {
  if (current === 0) {
    return validateSetUpAccount;
  }
  if (typeAcct === 'Business') {
    return validateBusinessForm;
  }
  return validateFreelancerForm;
};

export default validationSchema;
