import React, { useCallback, useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import lodash from 'lodash';
import { Modal, Button, Input, Form, Typography, Divider } from 'antd';
import {
  FacebookOutlined,
  TwitterOutlined,
  LinkedinOutlined,
  InstagramOutlined,
} from '@ant-design/icons';

const { Text } = Typography;
export const ModalAddUrl = props => {
  const { showModalAddUrl, onSubmit, formData } = props;
  const [websiteBusiness, setWebsiteBusiness] = useState('');

  useEffect(() => {
    setWebsiteBusiness(formData.companyWebsite || '');
  }, [showModalAddUrl, formData]);

  const onFinish = useCallback(
    value => {
      onSubmit({
        webSiteLinks: value.companyWebsite,
        socialMediaLinks: lodash.compact([
          value.facebookUrl,
          value.instagramUrl,
          value.twitterUrl,
          value.linkedinUrl,
        ]),
      });
    },
    [formData],
  );

  const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
  };

  return (
    <ModalStyle
      cancelButtonProps
      closable={false}
      visible={showModalAddUrl}
      footer={null}
      centered
      width={500}
      bodyStyle={{ padding: '50px 70px' }}
    >
      <TitleWrapper>
        <TitleStyle>
          Your order has been confirmed! After your 14-day free trial, your card
          will be charged. {'\n'} While we input your data, why not add your
          socials to your profile!
        </TitleStyle>
      </TitleWrapper>

      <FormStyle
        initialValues={{
          companyWebsite: `${websiteBusiness}`,
        }}
        name="basic"
        onFinish={onFinish}
        onFinishFailed={onFinishFailed}
      >
        <Form.Item name="companyWebsite">
          <InputStyled
            name="companyWebsite"
            type="text"
            size="large"
            placeholder="Enter your website"
          />
        </Form.Item>

        <Divider orientation="center" plain>
          Social Media Account Urls
        </Divider>
        <Form.Item name="facebookUrl">
          <InputStyled
            type="text"
            size="large"
            prefix={<FacebookOutlined />}
            placeholder="Enter your facebook media account urls"
          />
        </Form.Item>
        <Form.Item name="instagramUrl">
          <InputStyled
            type="text"
            size="large"
            prefix={<InstagramOutlined />}
            placeholder="Enter your instagram media account urls"
          />
        </Form.Item>
        <Form.Item name="twitterUrl">
          <InputStyled
            type="text"
            size="large"
            prefix={<TwitterOutlined />}
            placeholder="Enter your twitter media account urls"
          />
        </Form.Item>
        <Form.Item name="linkedinUrl">
          <InputStyled
            type="text"
            size="large"
            prefix={<LinkedinOutlined />}
            placeholder="Enter your linkedin media account urls"
          />
        </Form.Item>
        <ConfirmDescription>
          Press OK to complete your subscription
        </ConfirmDescription>
        <Form.Item>
          <ButtonStyle type="primary" htmlType="submit">
            Ok
          </ButtonStyle>
        </Form.Item>
      </FormStyle>
    </ModalStyle>
  );
};

ModalAddUrl.propTypes = {
  showModalAddUrl: PropTypes.bool,
  onSubmit: PropTypes.func,
  formData: PropTypes.any,
};

const ModalStyle = styled(Modal)`
  border-radius: 10px;
`;
const ConfirmDescription = styled(Text)`
  align-text: center;
`;
const TitleWrapper = styled.div`
  margin-bottom: 20px;
`;

const TitleStyle = styled.span`
  font-size: 18px;
`;

const FormStyle = styled(Form)`
  text-align: left;
`;

const InputStyled = styled(Input)`
  padding: 10px;
  width: 100%;
  .ant-input-prefix {
    margin-right: 10px;
  }
`;

const ButtonStyle = styled(Button)`
  width: 100%;
  margin-top: 5px;
`;
