import request from 'superagent';
import api from '../api/index';

const noop = (data, done) => done(null, data);
let jwtToken = null;

/**
 *
 * @param actions
 * @returns {*}
 */
export function createApi(actions) {
  const instance = {};

  // eslint-disable-next-line guard-for-in, no-restricted-syntax
  for (const name in actions) {
    instance[name] = createRequest(actions[name]);
  }

  return instance;
}

/**
 *
 * @param token
 */
export function setJWTToken(token) {
  api.apiClient.setToken(token);
  jwtToken = token;
}

export function getJWTToken() {
  return jwtToken;
}

export function reduxAction() {}

/**
 *
 * @param opts
 * @returns {Function}
 */
function createRequest(opts) {
  const { url: baseUrl, method = 'get', validate = noop } = opts;
  const sendType = method === 'get' || method === 'header' ? 'query' : 'send';
  const urlParams = getUrlParams(baseUrl);

  return (data = null, done) =>
    validate(data, () => {
      const url = replaceUrlParams(baseUrl, urlParams, data);
      const req = request(method, url);
      const token = api.apiClient.getToken();

      if (data) req[sendType](data);
      if (token) req.set('Authorization', `Bearer ${token}`);

      // eslint-disable-next-line consistent-return
      req.end((err, res) => {
        if (err) return done(res ? res.body || err : err);
        done(null, res.body);
      });
    });
}

/**
 *
 * @param url
 * @returns {{}}
 */
function getUrlParams(url) {
  // eslint-disable-next-line no-useless-escape
  const re = /:([^\/\?]+)/g;
  const params = {};
  let g;

  // eslint-disable-next-line no-cond-assign
  while ((g = re.exec(url))) {
    // eslint-disable-next-line prefer-destructuring
    params[g[1]] = g[0];
  }

  return params;
}

/**
 *
 * @param url
 * @param urlParams
 * @param data
 * @returns {*}
 */
function replaceUrlParams(url, urlParams, data) {
  if (!data) return url;

  // eslint-disable-next-line guard-for-in, no-restricted-syntax
  for (const key in urlParams) {
    // eslint-disable-next-line no-param-reassign
    url = url.replace(urlParams[key], data[key]);
  }

  return url;
}
