/**
 *
 * @param {Object} opts
 * @param {Function} [opts.preFn]
 * @param {Function} opts.fn
 * @param {String|Function} opts.success
 * @param {String|Function} opts.error
 * @param {Function} opts.postSuccess
 * @returns {Function}
 */
export function createAsyncAction(opts) {
  const { preFn, fn, success, error, transformData, postSuccess } = opts;
  const createSuccess =
    typeof success === 'function'
      ? success
      : body => ({ type: success, data: body });
  const createError =
    typeof error === 'function' ? error : err => ({ type: error, error: err });

  return data => (dispatch, getState) => {
    if (preFn) preFn(dispatch, getState, data);
    // eslint-disable-next-line no-param-reassign
    if (transformData) data = transformData(data, getState);

    fn(data, (err, res) => {
      const event = err ? createError(err, data) : createSuccess(res, data);
      dispatch(event);

      if (!err && postSuccess) postSuccess(dispatch, getState);
    });
  };
}
