import { browserHistory } from 'react-router-dom';
import AuthApi from '../../api/auth.api';
import { USER_LOGIN_SUCCESS, USER_LOGIN_FAILURE } from '../auth/auth.acitons';
// eslint-disable-next-line import/named
import { setJwt } from '../../utils/auth.utils';

const prefix = '@signup/';

export const SIGNUP_PENDING = `${prefix}SIGNUP_PENDING`;
export const SIGNUP_SUCCESS = `${prefix}SIGNUP_SUCCESS`;
export const SIGNUP_FAIL = `${prefix}SIGNUP_FAIL`;
export const RESET_STATE = `${prefix}RESET_STATE`;

export const resetState = () => ({ type: RESET_STATE });

export const signup = registrationFormData => dispatch => {
  console.log('registrationFormData', registrationFormData);
  dispatch({ type: SIGNUP_PENDING });

  const objectToSignup = {
    email: registrationFormData.email,
    password: registrationFormData.password,
    confirmPassword: registrationFormData.confirmPassword,
    userName:
      registrationFormData.typeAccount === 'Business'
        ? registrationFormData.companyName
        : registrationFormData.profile,
    role: registrationFormData.typeAccount,
    locations: registrationFormData.city,
    categories: registrationFormData.categories,
  };

  if (registrationFormData.typeAccount === 'Business') {
    objectToSignup.companyName =
      registrationFormData.businessDetails.companyName;
    objectToSignup.firstName = registrationFormData.businessDetails.firstName;
    objectToSignup.lastName = registrationFormData.businessDetails.lastName;
    objectToSignup.title = registrationFormData.businessDetails.title;
    objectToSignup.website = registrationFormData.businessDetails.website;
    objectToSignup.profile = registrationFormData.businessDetails.profile;
    objectToSignup.numberOfFullTimeEmployees = Number(
      registrationFormData.businessDetails.numberOfFullTimeEmployees // eslint-disable-line
    );
    objectToSignup.selected = registrationFormData.businessDetails.selected;
    objectToSignup.category = registrationFormData.businessDetails.category;
    objectToSignup.primaryCategory =
      registrationFormData.businessDetails.primaryCategory;
    objectToSignup.primaryCity =
      registrationFormData.businessDetails.primaryCity;
    objectToSignup.address = registrationFormData.businessDetails.address;
    objectToSignup.unitApt = registrationFormData.businessDetails.unitApt;
    objectToSignup.city = registrationFormData.businessDetails.city;
    objectToSignup.state = registrationFormData.businessDetails.state;
    objectToSignup.zip = registrationFormData.businessDetails.zip;
    objectToSignup.phone = registrationFormData.businessDetails.phone;
  } else {
    objectToSignup.firstName = registrationFormData.freelancerDetails.firstName;
    objectToSignup.lastName = registrationFormData.freelancerDetails.lastName;
    objectToSignup.profile = registrationFormData.freelancerDetails.profile;
    objectToSignup.selected = registrationFormData.freelancerDetails.selected;
    objectToSignup.primaryCategory =
      registrationFormData.freelancerDetails.primaryCategory;
    objectToSignup.address = registrationFormData.freelancerDetails.address;
    objectToSignup.unitApt = registrationFormData.freelancerDetails.unitApt;
    objectToSignup.city = registrationFormData.freelancerDetails.city;
    objectToSignup.state = registrationFormData.freelancerDetails.state;
    objectToSignup.zip = registrationFormData.freelancerDetails.zip;
    objectToSignup.phone = registrationFormData.freelancerDetails.phone;
  }
  // eslint-disable-next-line consistent-return
  return AuthApi.signup(objectToSignup, err => {
    if (err) {
      return dispatch({ type: SIGNUP_FAIL, payload: err });
    }
    AuthApi.login(
      {
        email: registrationFormData.email,
        password: registrationFormData.password,
        rememberMe: false,
      },
      // eslint-disable-next-line consistent-return
      (error, responseAuth) => {
        if (error) {
          return dispatch({ type: USER_LOGIN_FAILURE });
        }
        dispatch({ type: USER_LOGIN_SUCCESS, body: responseAuth });
        setJwt(responseAuth.jwt);
        browserHistory.push('/home');
      },
    );
  });
};
