import jwtDecode from 'jwt-decode';
import api from '../api/index';
import { setJWTToken } from '../libs/rapi';

const JWT_KEY = 'jwt';
const REMEMBER_ME = 'rememberMe';

// eslint-disable-next-line consistent-return
export function getCookie(name) {
  const value = `; ${document.cookie}`;
  const parts = value.split(`; ${name}=`);

  if (parts.length === 2)
    return parts
      .pop()
      .split(';')
      .shift();
}

/**
 *
 * @returns {boolean} return false if jwt is not set
 */
export function checkAndSetJWT() {
  const jwt = getCookie('jwt');
  if (!jwt) return false;

  setJWTToken(jwt);
  return true;
}

export function isAdmin() {
  return jwtDecode(api.apiClient.getToken()).role === 'admin';
}

export function checkJwt() {
  return !!api.apiClient.getToken();
}

export function setJwt(token) {
  api.apiClient.setJwt(token);
}

export function checkIfRememberWhenLogin() {
  const rememberMe = getCookie('rememberMe');
  return rememberMe === 1;
}

/**
 *
 */
export function resetToken() {
  document.cookie = `${JWT_KEY}=; Path=/; expires=Thu, 01 Jan 1970 00:00:01 GMT;`;
  document.cookie = `${REMEMBER_ME}=; Path=/; expires=Thu, 01 Jan 1970 00:00:01 GMT;`;
  setJWTToken(null);
}
